#!/bin/ksh
#
#  ORIGINS: 27
#
#  (C) COPYRIGHT International Business Machines Corp. 2002
#  All Rights Reserved
#
#  US Government Users Restricted Rights - Use, duplication or
#  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# Written:	August 16, 2002
# By:		Jennifer Dietrich and John W Sullivan, IBM - Austin
#
# Purpose:	This script should be run after the installation of WebSphere
#		Server 4.04.  This script will clean up all lppchk errors
#		related to the installation of WebSphere and IHS on the system.
#		There is no checking to see if lppchk may be reporting a valid
#		error for these products; all errors are cleaned up.
#
#	Note: This script must be executed as the root user.
#
#

export LC_ALL=C

if [ -z "$TMP" ]; then 
   OUTDIR=$PWD/was_clean.$$
else
   OUTDIR=$TMP/was_clean.$$
fi;

IMAGE_LIST=$OUTDIR/image_list

# Create a directory to store the output as we go along
mkdir $OUTDIR >/dev/null 2>&1

# Get the list of WebSphere products installed on the system with WAS 4.01
# so that each can be processed and cleaned up.
lslpp -qacl IBMWebAS\* http_server\* 2>/dev/null | cut -f1,2 -d: > $IMAGE_LIST

# Process each fileset one at a time
cat $IMAGE_LIST | while IFS=: read ODMDIR fileset
do
# Set ODMDIR for this iteration
export ODMDIR

# Get the list of all of the lppchk errors for the fileset
lppchk -c $fileset 2> $OUTDIR/$fileset.lppchk

# If there are errors to clean up, CONTINUE
if [ -s $OUTDIR/$fileset.lppchk ]
then

# Get the lpp_id of the fileset
lpp_id=`odmget -q name=$fileset lpp | awk '/lpp_id/{print $3}'`

# Remove the missing files from the inventory database
grep "could not be located." $OUTDIR/$fileset.lppchk | awk '{print $3 }' |
while read file
do
odmdelete -o inventory -q"loc0=$file and lpp_id=$lpp_id" >/dev/null 2>&1
done

# Process the files with bad cksums and bad size info
grep "The checksum for file" $OUTDIR/$fileset.lppchk | awk '{print $6 }' > $OUTDIR/$fileset.volatile
grep "Size of" $OUTDIR/$fileset.lppchk | awk '{print $4 }' >> $OUTDIR/$fileset.volatile

# Are there checksum or size errors to work with?
if [ -s $OUTDIR/$fileset.volatile ]
then
# CONTINUE because there are errors to work with

# Sort and uniq the list to make sure we don't process any file twice
sort $OUTDIR/$fileset.volatile > $OUTDIR/sort
uniq $OUTDIR/sort > $OUTDIR/$fileset.volatile

# Process each file and change the cksum and size values to VOLATILE
cat $OUTDIR/$fileset.volatile | while read file
do
echo "inventory: size = 0\nchecksum = 0" | odmchange -o inventory -q"loc0=$file and lpp_id=$lpp_id"
done
fi
fi

rm -f $OUTDIR/$fileset.* 2>/dev/null

done

rm -rf $OUTDIR 2>/dev/null

exit 0
